Learn R Programming

fBasics (version 4021.92)

BasicStatistics: Basic Time Series Statistics

Description

Computes basic financial time series statististics.

List of Functions:

basicStatsComputes an overview of basic statistical values.

Usage

basicStats(x, ci = 0.95)

Value

basicsStats


returns a data frame with the following entries and row names: nobs, NAs, Minimum, Maximum , 1. Quartile, 3. Quartile, Mean, Median, Sum, SE Mean, LCL Mean, UCL Mean, Variance, Stdev, Skewness, Kurtosis.

Arguments

ci

confidence interval, a numeric value, by default 0.95, i.e. 95 percent.

x

an object of class "timeSeries" or any other object which can be transformed by the function as.timeSeries into an object of class timeSeries. The latter case, other then timeSeries objects, is more or less untested.

Examples

Run this code
## basicStats -
   # Simulated Monthly Return Data:
   tS = timeSeries(matrix(rnorm(12)), timeDate::timeCalendar())
   basicStats(tS)

Run the code above in your browser using DataLab