A collection and description of moment and maximum
likelihood estimators to fit the parameters of a
distribution.
The functions are:
nFit | MLE parameter fit for a normal distribution, |
tFit | MLE parameter fit for a Student t-distribution, |
stableFit | MLE and Quantile Method stable parameter fit. |
nFit(x, doplot = TRUE, span = "auto", title = NULL, description = NULL, ...)tFit(x, df = 4, doplot = TRUE, span = "auto", trace = FALSE, title = NULL,
description = NULL, ...)
stableFit(x, alpha = 1.75, beta = 0, gamma = 1, delta = 0,
type = c("q", "mle"), doplot = TRUE, control = list(),
trace = FALSE, title = NULL, description = NULL)
# S4 method for fDISTFIT
show(object)
The functions tFit, hypFit and nigFit return
a list with the following components:
the point at which the maximum value of the log liklihood function is obtained.
the value of the estimated maximum, i.e. the value of the log liklihood function.
an integer indicating why the optimization process terminated.
the gradient at the estimated maximum.
Remark: The parameter estimation for the stable distribution via the maximum Log-Likelihood approach may take a quite long time.
[stableFit] -
a list of control parameters, see function nlminb.
[stable] -
The parameters are alpha, beta, gamma,
and delta:
value of the index parameter alpha with alpha = (0,2];
skewness parameter beta, in the range [-1, 1];
scale parameter gamma; and
shift parameter delta.
a character string which allows for a brief description.
the number of degrees of freedom for the Student distribution,
df > 2, maybe non-integer. By default a value of 4 is
assumed.
[show] -
an S4 class object as returned from the fitting functions.
a logical flag. Should a plot be displayed?
x-coordinates for the plot, by default 100 values
automatically selected and ranging between the 0.001,
and 0.999 quantiles. Alternatively, you can specify
the range by an expression like span=seq(min, max,
times = n), where, min and max are the
left and right endpoints of the range, and n gives
the number of the intermediate points.
a character string which allows for a project title.
a logical flag. Should the parameter estimation process be traced?
a character string which allows to select the method for
parameter estimation: "mle", the maximum log likelihood
approach, or "qm", McCulloch's quantile method.
a numeric vector.
parameters to be parsed.
Stable Parameter Estimation:
Estimation techniques based on the quantiles of an empirical sample
were first suggested by Fama and Roll [1971]. However their technique
was limited to symmetric distributions and suffered from a small
asymptotic bias. McCulloch [1986] developed a technique that uses
five quantiles from a sample to estimate alpha and beta
without asymptotic bias. Unfortunately, the estimators provided by
McCulloch have restriction alpha>0.6.
## nFit -
# Simulate random normal variates N(0.5, 2.0):
set.seed(1953)
s = rnorm(n = 1000, 0.5, 2)
## nigFit -
# Fit Parameters:
nFit(s, doplot = TRUE)
Run the code above in your browser using DataLab