Learn R Programming

fBasics (version 4021.92)

ReturnSeriesGUI: Return Series Plots

Description

A graphical user interface to display finanical time series plots.

List of Functions:

returnSeriesGUIOpens a GUI for return series plots.

Usage

returnSeriesGUI(x)

Value

returnSeriesGUI


For the returnSeriesGUI function, beside the graphical user interface no values are returned.

Arguments

x

an object of class "timeSeries" or any other object which can be transformed by the function as.timeSeries into an object of class timeSeries. The latter case, other then timeSeries objects, is more or less untested.

Author

Diethelm Wuertz for the Rmetrics R-port.

Examples

Run this code
## 

Run the code above in your browser using DataLab