Learn R Programming

fBasics (version 4021.92)

characterTable: Table of Characters

Description

Displays a table of numerical equivalents to Latin characters.

Usage

characterTable(font = 1, cex = 0.7)

Value

characterTable

displays a table with the characters of the requested font. The character on line "xy" and column "z" of the table has code "\xyz", e.g cat("\126") prints: V for font number 1. These codes can be used as any other characters.

Arguments

cex

a numeric value, determines the character size, the default size is 0.7.

font

an integer value, the number of the font, by default font number 1.

See Also

link{colorTable}, link{symbolTable}.

Examples

Run this code
## Character Table for Font 2:
# characterTable(font = 1)

Run the code above in your browser using DataLab