powered by
Displays a Table of color codes and plots the colors themselves.
colorTable(cex = 0.7)
colorTable
returns a table of plot plot colors with the associated color numbers.
a numeric value, determines the character size in the color plot, the default size is 0.7.
link{characterTable}, link{symbolTable}.
link{characterTable}
link{symbolTable}
## Color Table: colorTable()
Run the code above in your browser using DataLab