Class representation, methods and utility
functions for objects of class 'fHTEST'.
The class representation and methods are:
fHTEST | Representation for an S4 object of class "fHTEST", |
show | S4 print method. |
# S4 method for fHTEST
show(object)
In contrast to R's output report from S3 objects of class "htest"
a different output report is produced. The tests return an S4 object
of class "fHTEST". The object contains the following slots:
the function call.
the data as specified by the input argument(s).
a list whose elements contain the results from the statistical
test. The information provided is similar to a list object of
class "htest".
a character string with the name of the test. This can be overwritten specifying a user defined input argument.
a character string with an optional user defined description. By default just the current date when the test was applied will be returned.
The slot @test returns an object of class "list"
containing the following elements:
the value(s) of the test statistic.
the p-value(s) of the test.
a numeric value or vector of parameters.
a numeric value or vector of sample estimates.
a numeric two row vector or matrix of 95
a character string indicating what type of test was performed.
a character string giving the name(s) of the data.
[show] -
an S4 object of class "fHTEST".
## fHTEST -
getClass("fHTEST")
getSlots("fHTEST")
Run the code above in your browser using DataLab