powered by
Lists the content of an index file.
listIndex(package, character.only = FALSE)
prints the index file.
a literal character string or a character string denoting the name of the package to be listed.
a logical indicating whether 'package' can be assumed to be character strings.
listDescription, listIndex.
listDescription
listIndex
## listIndex - listIndex("fBasics")
Run the code above in your browser using DataLab