Tests if two series differ in their distributional scale parameter.
scaleTest(x, y, method = c("ansari", "mood"),
title = NULL, description = NULL)
In contrast to R's output report from S3 objects of class "htest"
a different output report is produced. The classical tests presented
here return an S4 object of class "fHTEST". The object contains
the following slots:
the function call.
the data as specified by the input argument(s).
a list whose elements contain the results from the statistical
test. The information provided is similar to a list object of
class "htest".
a character string with the name of the test. This can be overwritten specifying a user defined input argument.
a character string with an optional user defined description. By default just the current date when the test was applied will be returned.
The slot @test returns an object of class "list"
containing (at least) the following elements:
the value(s) of the test statistic.
the p-value(s) of the test.
a numeric value or vector of parameters.
a numeric value or vector of sample estimates.
a numeric two row vector or matrix of 95
a character string indicating what type of test was performed.
a character string giving the name(s) of the data.
numeric vectors of data values.
a character string naming which test should be applied.
an optional title string, if not specified the inputs data name is deparsed.
optional description string, or a vector of character strings.
R-core team for hypothesis tests implemented from R's
package ctest.
The method="ansari" performs the Ansari--Bradley two--sample
test for a difference in scale parameters. The test returns for
any sizes of the series x and y the exact p value
together with its asymptotic limit.
The method="mood", is another test which performs a
two--sample test for a difference in scale parameters. The underlying
model is that the two samples are drawn from f(x-l) and
f((x-l)/s)/s, respectively, where l is a common
location parameter and s is a scale parameter. The null
hypothesis is s=1.
Conover, W. J. (1971); Practical nonparametric statistics, New York: John Wiley & Sons.
Lehmann E.L. (1986); Testing Statistical Hypotheses, John Wiley and Sons, New York.
Moore, D.S. (1986); Tests of the chi-squared type, In: D'Agostino, R.B. and Stephens, M.A., eds., Goodness-of-Fit Techniques, Marcel Dekker, New York.
## rnorm -
# Generate Series:
x = rnorm(50)
y = rnorm(50)
## scaleTest -
scaleTest(x, y, "ansari")
scaleTest(x, y, "mood")
Run the code above in your browser using DataLab