Learn R Programming

fBasics (version 4021.92)

ssdFit: Fit Density Using Smoothing Splines

Description

Estimates the parameters of a density function using smoothing splines.

Usage

ssdFit(x)

Value

The function ssdFit, hypFit returns an object of class

ssden. The returned object can be used to evaluate density, probabilities and quantiles.

Arguments

x

a numeric vector.

Author

Diethelm Wuertz, Chong Gu for the underlying gss package.

References

Gu, C. (2002), Smoothing Spline ANOVA Models, New York Springer--Verlag.

Gu, C. and Wang, J. (2003), Penalized likelihood density estimation: Direct cross-validation and scalable approximation, Statistica Sinica, 13, 811--826.

Examples

Run this code
## ssdFit -
   set.seed(1953)
   r = rnorm(500)
   hist(r, breaks = "FD", probability = TRUE,
     col = "steelblue", border = "white")
 
## ssdFit - 
   param = ssdFit(r)
   
## dssd -  
   u = seq(min(r), max(r), len = 301)
   v = dssd(u, param)
   lines(u, v, col = "orange", lwd = 2)

Run the code above in your browser using DataLab