Learn R Programming

fBasics (version 4021.92)

symbolTable: Table of Symbols

Description

Displays a Table of plot characters and symbols.

Usage

symbolTable(font = par('font'), cex = 0.7)

Value

symbolTable

displays a table with the plot characters and symbols numbered from 0 to 255 and returns invisible the name of the font.

Arguments

cex

a numeric value, determines the character size, the default size is 0.7.

font

an integer value, the number of the font, by default font number 1.

See Also

link{characterTable}, link{colorTable}.

Examples

Run this code
## symbolTable - 
   # Default Symbol Table:
# symbolTable()

Run the code above in your browser using DataLab