powered by
Displays a Table of plot characters and symbols.
symbolTable(font = par('font'), cex = 0.7)
symbolTable
displays a table with the plot characters and symbols numbered from 0 to 255 and returns invisible the name of the font.
a numeric value, determines the character size, the default size is 0.7.
an integer value, the number of the font, by default font number 1.
font
link{characterTable}, link{colorTable}.
link{characterTable}
link{colorTable}
## symbolTable - # Default Symbol Table: # symbolTable()
Run the code above in your browser using DataLab